/***************************************************************************
 *   Copyright (C) 2007 Mikhail Fedotov                                    *
 *   anyremote@mail.ru                                                     *
 *   http://anyremote.sf.net                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

/* ANYREMOTE PLUGIN FOR THE KOPETE KDE INSTANT MESSANGER 
 *
 * contact specific settings base class implementation
 *
 */ 


#include <qstring.h>
#include <qcheckbox.h>
#include <qlineedit.h>
#include <qpushbutton.h>

#include <kdebug.h>

#include <kopetemetacontact.h>

#include "kopeteanyremoteuserprefs.h"
#include "kopeteanyremoteuserprefsui.h"
#include "kopeteanyremoteplugin.h"
#include "kopete_anyremote.h"


KopeteAnyremoteUserPrefs::KopeteAnyremoteUserPrefs( Kopete::MetaContact* mc ) : QObject(),
		metaContact( mc )
{
	loadConfig();
	this->contactSettingsDialog = new KopeteAnyremoteUserPrefsUI();

	QObject::connect( this->contactSettingsDialog->btOK, SIGNAL( pressed() ), this, SLOT( slotOkButtonPressed() ) );
	QObject::connect( contactSettingsDialog->btCancel, SIGNAL( pressed() ), this, SLOT( slotCancelButtonPressed() ) );
}


QString KopeteAnyremoteUserPrefs::bool2string( bool b )
{
	return ( b ? "true" : "false" );
}


bool KopeteAnyremoteUserPrefs::string2bool( QString s )
{
	return ( s == "true" ? true : false );
}


void KopeteAnyremoteUserPrefs::showContactSettingsDialog()
{
	this->contactSettingsDialog->cbOverrideReadIncomingMessages->setChecked( this->overrideReadIncomingMessages );
	this->contactSettingsDialog->cbReadIncomingMessages->setChecked( this->readIncomingMessages );
	this->contactSettingsDialog->cbOverrideReadOutgoingMessages->setChecked( this->overrideReadOutgoingMessages );
	this->contactSettingsDialog->cbReadOutgoingMessages->setChecked( this->readOutgoingMessages );
	this->contactSettingsDialog->cbOverrideAnnounceStatusChanges->setChecked( this->overrideAnnounceStatusChanges );
	this->contactSettingsDialog->cbAnnounceStatusChanges->setChecked( this->announceStatusChanges );

	this->contactSettingsDialog->show();
}


void KopeteAnyremoteUserPrefs::loadConfig()
{
	this->overrideReadIncomingMessages = KopeteAnyremoteUserPrefs::string2bool( this->metaContact->pluginData( KopeteAnyremotePlugin::self(), "overrideReadIncomingMessages" )  );
	this->readIncomingMessages = KopeteAnyremoteUserPrefs::string2bool( this->metaContact->pluginData( KopeteAnyremotePlugin::self(), "readIncomingMessages" ) );
	this->overrideReadOutgoingMessages = KopeteAnyremoteUserPrefs::string2bool( this->metaContact->pluginData( KopeteAnyremotePlugin::self(), "overrideReadOutgoingMessages" )  );
	this->readOutgoingMessages = KopeteAnyremoteUserPrefs::string2bool( this->metaContact->pluginData( KopeteAnyremotePlugin::self(), "readOutgoingMessages" ) );
	this->overrideAnnounceStatusChanges = KopeteAnyremoteUserPrefs::string2bool( this->metaContact->pluginData( KopeteAnyremotePlugin::self(), "overrideAnnounceStatusChanges" ) );
	this->announceStatusChanges = KopeteAnyremoteUserPrefs::string2bool( this->metaContact->pluginData( KopeteAnyremotePlugin::self(), "announceStatusChanges" ) );
}


void KopeteAnyremoteUserPrefs::saveConfig()
{
	this->metaContact->setPluginData( KopeteAnyremotePlugin::self(), "overrideReadIncomingMessages", KopeteAnyremoteUserPrefs::bool2string( this->contactSettingsDialog->cbOverrideReadIncomingMessages->isChecked() ) );
	this->metaContact->setPluginData( KopeteAnyremotePlugin::self(), "readIncomingMessages", KopeteAnyremoteUserPrefs::bool2string( this->contactSettingsDialog->cbReadIncomingMessages->isChecked() ) );
	this->metaContact->setPluginData( KopeteAnyremotePlugin::self(), "overrideReadOutgoingMessages", KopeteAnyremoteUserPrefs::bool2string( this->contactSettingsDialog->cbOverrideReadOutgoingMessages->isChecked() ) );
	this->metaContact->setPluginData( KopeteAnyremotePlugin::self(), "readOutgoingMessages", KopeteAnyremoteUserPrefs::bool2string( this->contactSettingsDialog->cbReadOutgoingMessages->isChecked() ) );
	this->metaContact->setPluginData( KopeteAnyremotePlugin::self(), "overrideAnnounceStatusChanges", KopeteAnyremoteUserPrefs::bool2string( this->contactSettingsDialog->cbOverrideAnnounceStatusChanges->isChecked() ) );
	this->metaContact->setPluginData( KopeteAnyremotePlugin::self(), "announceStatusChanges", KopeteAnyremoteUserPrefs::bool2string( this->contactSettingsDialog->cbAnnounceStatusChanges->isChecked() ) );

	loadConfig();
}


void KopeteAnyremoteUserPrefs::slotOkButtonPressed()
{
	saveConfig();
	this->contactSettingsDialog->hide();
}


void KopeteAnyremoteUserPrefs::slotCancelButtonPressed()
{
	this->contactSettingsDialog->hide();
}

bool KopeteAnyremoteUserPrefs::getReadIncomingMessages()
{
	return ( this->overrideReadIncomingMessages ? this->readIncomingMessages : KopeteAnyremoteKcfg::readIncomingMessages() );
}

bool KopeteAnyremoteUserPrefs::getReadOutgoingMessages()
{
	return ( this->overrideReadOutgoingMessages ? this->readOutgoingMessages : KopeteAnyremoteKcfg::readOutgoingMessages() );
}

bool KopeteAnyremoteUserPrefs::getAnnounceStatusChanges()
{
	return ( this->overrideAnnounceStatusChanges ? this->announceStatusChanges : KopeteAnyremoteKcfg::announceStatusChanges() );
}

QString KopeteAnyremoteUserPrefs::getName()
{
	return this->metaContact->displayName();
}


#include "kopeteanyremoteuserprefs.moc"
